@@ -1,11 +1,11 @@
 function _ode_addsteps!(integrator, cache::RadauIIA3ConstantCache)
-    @unpack t, dt, uprev, u, f, p, k = integrator
-    @unpack T11, T12, T21, T22, TI11, TI12, TI21, TI22 = cache.tab
-    @unpack c1, c2, α, β, e1, e2 = cache.tab
-    @unpack κ, cont1, cont2 = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    (; t, dt, uprev, u, f, p, k) = integrator
+    (; T11, T12, T21, T22, TI11, TI12, TI21, TI22) = cache.tab
+    (; c1, c2, α, β, e1, e2) = cache.tab
+    (; κ, cont1, cont2) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations
@@ -41,7 +41,10 @@ function _ode_addsteps!(integrator, cache::RadauIIA3ConstantCache)
     integrator.stats.nw += 1
 
     # Newton iteration
-    local ndw, ff1, ff2
+    local ff1, ff2
+    # Initialize variables for JET
+    ndw = one(eltype(u))
+    ndwprev = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -72,7 +75,7 @@ function _ode_addsteps!(integrator, cache::RadauIIA3ConstantCache)
         dw2 = imag(dw12)
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         atmp1 = calculate_residuals(dw1, uprev, u, atol, rtol, internalnorm, t)
         atmp2 = calculate_residuals(dw2, uprev, u, atol, rtol, internalnorm, t)
         ndw = internalnorm(atmp1, t) + internalnorm(atmp2, t)
@@ -86,6 +89,7 @@ function _ode_addsteps!(integrator, cache::RadauIIA3ConstantCache)
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         w1 = @. w1 - dw1
@@ -96,7 +100,6 @@ function _ode_addsteps!(integrator, cache::RadauIIA3ConstantCache)
         z2 = @. T21 * w1 + T22 * w2
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -123,18 +126,18 @@ function _ode_addsteps!(integrator, cache::RadauIIA3ConstantCache)
 end
 
 function _ode_addsteps!(integrator, cache::RadauIIA3Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, fsallast, fsalfirst = integrator
-    @unpack T11, T12, T21, T22, TI11, TI12, TI21, TI22 = cache.tab
-    @unpack c1, c2, α, β, e1, e2 = cache.tab
-    @unpack κ = cache
-    @unpack z1, z2, w1, w2,
+    (; t, dt, uprev, u, f, p, fsallast, fsalfirst) = integrator
+    (; T11, T12, T21, T22, TI11, TI12, TI21, TI22) = cache.tab
+    (; c1, c2, α, β, e1, e2) = cache.tab
+    (; κ) = cache
+    (; z1, z2, w1, w2,
     dw12, cubuff,
     k, k2, fw1, fw2,
     J, W1,
-    tmp, atmp, jac_config, rtol, atol, step_limiter! = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    tmp, atmp, jac_config, rtol, atol, step_limiter!) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
     # precalculations
     αdt, βdt = α / dt, β / dt
@@ -166,7 +169,9 @@ function _ode_addsteps!(integrator, cache::RadauIIA3Cache, repeat_step = false)
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
+    ndwprev = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -218,7 +223,7 @@ function _ode_addsteps!(integrator, cache::RadauIIA3Cache, repeat_step = false)
         dw2 = imag(dw12)
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         calculate_residuals!(atmp, dw1, uprev, u, atol, rtol, internalnorm, t)
         ndw1 = internalnorm(atmp, t)
         calculate_residuals!(atmp, dw2, uprev, u, atol, rtol, internalnorm, t)
@@ -232,6 +237,7 @@ function _ode_addsteps!(integrator, cache::RadauIIA3Cache, repeat_step = false)
             if diverge
                 break
             end
+            η = θ / (1 - θ)
         end
 
         @. w1 = w1 - dw1
@@ -242,7 +248,6 @@ function _ode_addsteps!(integrator, cache::RadauIIA3Cache, repeat_step = false)
         @. z2 = T21 * w1 + T22 * w2
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -277,14 +282,14 @@ end
 
 function _ode_addsteps!(integrator, cache::RadauIIA5ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, k = integrator
-    @unpack T11, T12, T13, T21, T22, T23, T31, TI11, TI12, TI13,
-    TI21, TI22, TI23, TI31, TI32, TI33 = cache.tab
-    @unpack c1, c2, γ, α, β, e1, e2, e3 = cache.tab
-    @unpack κ, cont1, cont2, cont3 = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    (; t, dt, uprev, u, f, p, k) = integrator
+    (; T11, T12, T13, T21, T22, T23, T31, TI11, TI12, TI13,
+    TI21, TI22, TI23, TI31, TI32, TI33) = cache.tab
+    (; c1, c2, γ, α, β, e1, e2, e3) = cache.tab
+    (; κ, cont1, cont2, cont3) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations
@@ -330,7 +335,8 @@ function _ode_addsteps!(integrator, cache::RadauIIA5ConstantCache,
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -368,7 +374,7 @@ function _ode_addsteps!(integrator, cache::RadauIIA5ConstantCache,
         dw3 = imag(dw23)
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         atmp1 = calculate_residuals(dw1, uprev, u, atol, rtol, internalnorm, t)
         atmp2 = calculate_residuals(dw2, uprev, u, atol, rtol, internalnorm, t)
         atmp3 = calculate_residuals(dw3, uprev, u, atol, rtol, internalnorm, t)
@@ -382,6 +388,7 @@ function _ode_addsteps!(integrator, cache::RadauIIA5ConstantCache,
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         w1 = @.. w1-dw1
@@ -394,7 +401,6 @@ function _ode_addsteps!(integrator, cache::RadauIIA5ConstantCache,
         z3 = @.. T31 * w1+w2           # T32 = 1, T33 = 0
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -427,19 +433,19 @@ function _ode_addsteps!(integrator, cache::RadauIIA5ConstantCache,
 end
 
 function _ode_addsteps!(integrator, cache::RadauIIA5Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, fsallast, fsalfirst, k = integrator
-    @unpack T11, T12, T13, T21, T22, T23, T31, TI11, TI12, TI13,
-    TI21, TI22, TI23, TI31, TI32, TI33 = cache.tab
-    @unpack c1, c2, γ, α, β, e1, e2, e3 = cache.tab
-    @unpack κ = cache
-    @unpack z1, z2, z3, w1, w2, w3,
+    (; t, dt, uprev, u, f, p, fsallast, fsalfirst, k) = integrator
+    (; T11, T12, T13, T21, T22, T23, T31, TI11, TI12, TI13,
+    TI21, TI22, TI23, TI31, TI32, TI33) = cache.tab
+    (; c1, c2, γ, α, β, e1, e2, e3) = cache.tab
+    (; κ) = cache
+    (; z1, z2, z3, w1, w2, w3,
     dw1, ubuff, dw23, cubuff,
     k, k2, k3, fw1, fw2, fw3,
     J, W1, W2,
-    tmp, atmp, jac_config, linsolve1, linsolve2, rtol, atol, step_limiter! = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    tmp, atmp, jac_config, linsolve1, linsolve2, rtol, atol, step_limiter!) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations
@@ -485,7 +491,8 @@ function _ode_addsteps!(integrator, cache::RadauIIA5Cache, repeat_step = false)
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -563,7 +570,7 @@ function _ode_addsteps!(integrator, cache::RadauIIA5Cache, repeat_step = false)
         @.. dw3=imag(dw23)
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         calculate_residuals!(atmp, dw1, uprev, u, atol, rtol, internalnorm, t)
         ndw1 = internalnorm(atmp, t)
         calculate_residuals!(atmp, dw2, uprev, u, atol, rtol, internalnorm, t)
@@ -581,6 +588,7 @@ function _ode_addsteps!(integrator, cache::RadauIIA5Cache, repeat_step = false)
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         @.. w1=w1 - dw1
@@ -593,7 +601,6 @@ function _ode_addsteps!(integrator, cache::RadauIIA5Cache, repeat_step = false)
         @.. z3=T31 * w1 + w2           # T32 = 1, T33 = 0
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -630,17 +637,17 @@ end
 
 function _ode_addsteps!(integrator, cache::RadauIIA9ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, k = integrator
-    @unpack T11, T12, T13, T14, T15, T21, T22, T23, T24, T25, T31, T32,
-    T33, T34, T35, T41, T42, T43, T44, T45, T51 = cache.tab#= T52 = 1, T53 = 0, T54 = 1, T55 = 0=#
-    @unpack TI11,
+    (; t, dt, uprev, u, f, p, k) = integrator
+    (; T11, T12, T13, T14, T15, T21, T22, T23, T24, T25, T31, T32,
+    T33, T34, T35, T41, T42, T43, T44, T45, T51) = cache.tab#= T52 = 1, T53 = 0, T54 = 1, T55 = 0=#
+    (; TI11,
     TI12, TI13, TI14, TI15, TI21, TI22, TI23, TI24, TI25, TI31, TI32, TI33, TI34,
-    TI35, TI41, TI42, TI43, TI44, TI45, TI51, TI52, TI53, TI54, TI55 = cache.tab
-    @unpack c1, c2, c3, c4, γ, α1, β1, α2, β2, e1, e2, e3, e4, e5 = cache.tab
-    @unpack κ = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    TI35, TI41, TI42, TI43, TI44, TI45, TI51, TI52, TI53, TI54, TI55) = cache.tab
+    (; c1, c2, c3, c4, γ, α1, β1, α2, β2, e1, e2, e3, e4, e5) = cache.tab
+    (; κ) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations rtol pow is (num stages + 1)/(2*num stages)
@@ -721,7 +728,8 @@ function _ode_addsteps!(integrator, cache::RadauIIA9ConstantCache,
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -772,7 +780,7 @@ function _ode_addsteps!(integrator, cache::RadauIIA9ConstantCache,
         dw5 = imag(dw45)
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         atmp1 = calculate_residuals(dw1, uprev, u, atol, rtol, internalnorm, t)
         atmp2 = calculate_residuals(dw2, uprev, u, atol, rtol, internalnorm, t)
         atmp3 = calculate_residuals(dw3, uprev, u, atol, rtol, internalnorm, t)
@@ -791,6 +799,7 @@ function _ode_addsteps!(integrator, cache::RadauIIA9ConstantCache,
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         w1 = @.. w1-dw1
@@ -807,7 +816,6 @@ function _ode_addsteps!(integrator, cache::RadauIIA9ConstantCache,
         z5 = @.. T51*w1+w2+w4#= T52=1, T53=0, T54=1, T55=0 =#
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -857,23 +865,23 @@ function _ode_addsteps!(integrator, cache::RadauIIA9ConstantCache,
 end
 
 function _ode_addsteps!(integrator, cache::RadauIIA9Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, fsallast, fslafirst, k = integrator
-    @unpack T11, T12, T13, T14, T15, T21, T22, T23, T24, T25, T31, T32,
-    T33, T34, T35, T41, T42, T43, T44, T45, T51 = cache.tab#= T52 = 1, T53 = 0, T54 = 1, T55 = 0=#
-    @unpack TI11,
+    (; t, dt, uprev, u, f, p, fsallast, fslafirst, k) = integrator
+    (; T11, T12, T13, T14, T15, T21, T22, T23, T24, T25, T31, T32,
+    T33, T34, T35, T41, T42, T43, T44, T45, T51) = cache.tab#= T52 = 1, T53 = 0, T54 = 1, T55 = 0=#
+    (; TI11,
     TI12, TI13, TI14, TI15, TI21, TI22, TI23, TI24, TI25, TI31, TI32, TI33, TI34,
-    TI35, TI41, TI42, TI43, TI44, TI45, TI51, TI52, TI53, TI54, TI55 = cache.tab
-    @unpack c1, c2, c3, c4, γ, α1, β1, α2, β2, e1, e2, e3, e4, e5 = cache.tab
-    @unpack κ = cache
-    @unpack z1, z2, z3, z4, z5, w1, w2, w3, w4, w5 = cache
-    @unpack dw1, ubuff, dw23, dw45, cubuff1, cubuff2 = cache
-    @unpack k, k2, k3, k4, k5, fw1, fw2, fw3, fw4, fw5 = cache
-    @unpack J, W1, W2, W3 = cache
-    @unpack tmp, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7, tmp8, tmp9, tmp10, atmp, jac_config,
-    linsolve1, linsolve2, linsolve3, rtol, atol, step_limiter! = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    TI35, TI41, TI42, TI43, TI44, TI45, TI51, TI52, TI53, TI54, TI55) = cache.tab
+    (; c1, c2, c3, c4, γ, α1, β1, α2, β2, e1, e2, e3, e4, e5) = cache.tab
+    (; κ) = cache
+    (; z1, z2, z3, z4, z5, w1, w2, w3, w4, w5) = cache
+    (; dw1, ubuff, dw23, dw45, cubuff1, cubuff2) = cache
+    (; k, k2, k3, k4, k5, fw1, fw2, fw3, fw4, fw5) = cache
+    (; J, W1, W2, W3) = cache
+    (; tmp, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7, tmp8, tmp9, tmp10, atmp, jac_config,
+    linsolve1, linsolve2, linsolve3, rtol, atol, step_limiter!) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations
@@ -952,7 +960,8 @@ function _ode_addsteps!(integrator, cache::RadauIIA9Cache, repeat_step = false)
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -1069,7 +1078,7 @@ function _ode_addsteps!(integrator, cache::RadauIIA9Cache, repeat_step = false)
         @.. dw5=imag(dw45)
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         calculate_residuals!(atmp, dw1, uprev, u, atol, rtol, internalnorm, t)
         ndw1 = internalnorm(atmp, t)
         calculate_residuals!(atmp, dw2, uprev, u, atol, rtol, internalnorm, t)
@@ -1092,6 +1101,7 @@ function _ode_addsteps!(integrator, cache::RadauIIA9Cache, repeat_step = false)
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         @.. w1=w1 - dw1
@@ -1108,8 +1118,6 @@ function _ode_addsteps!(integrator, cache::RadauIIA9Cache, repeat_step = false)
         @.. z5=T51 * w1 + w2 + w4#= T52=1, T53=0, T54=1, T55=0 =#
 
         # check stopping criterion
-
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -1155,14 +1163,14 @@ function _ode_addsteps!(integrator, cache::RadauIIA9Cache, repeat_step = false)
 end
 
 function _ode_addstep!(integrator, cache::AdaptiveRadauConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, k = integrator
-    @unpack tabs, num_stages, index = cache
+    (; t, dt, uprev, u, f, p, k) = integrator
+    (; tabs, num_stages, index) = cache
     tab = tabs[index]
-    @unpack T, TI, γ, α, β, c, e = tab
-    @unpack κ = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    (; T, TI, γ, α, β, c, e) = tab
+    (; κ) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations rtol pow is (num stages + 1)/(2*num stages)
@@ -1226,7 +1234,8 @@ function _ode_addstep!(integrator, cache::AdaptiveRadauConstantCache, repeat_ste
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -1278,7 +1287,7 @@ function _ode_addstep!(integrator, cache::AdaptiveRadauConstantCache, repeat_ste
         integrator.stats.nsolve += (num_stages + 1) ÷ 2
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         ndw = 0.0
         for i in 1:num_stages
             ndw += internalnorm(
@@ -1296,6 +1305,7 @@ function _ode_addstep!(integrator, cache::AdaptiveRadauConstantCache, repeat_ste
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         for i in 1:num_stages
@@ -1318,7 +1328,6 @@ function _ode_addstep!(integrator, cache::AdaptiveRadauConstantCache, repeat_ste
         end
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -1369,17 +1378,17 @@ function _ode_addstep!(integrator, cache::AdaptiveRadauConstantCache, repeat_ste
 end
 
 function _ode_addsteps!(integrator, cache::AdaptiveRadauCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, fsallast, fsalfirst, k = integrator
-    @unpack num_stages, tabs, index = cache
+    (; t, dt, uprev, u, f, p, fsallast, fsalfirst, k) = integrator
+    (; num_stages, tabs, index) = cache
     tab = tabs[index]
-    @unpack T, TI, γ, α, β, c, e = tab
-    @unpack κ, derivatives, z, w, c_prime, αdt, βdt = cache
-    @unpack dw1, ubuff, dw2, cubuff, dw = cache
-    @unpack ks, k, fw, J, W1, W2 = cache
-    @unpack tmp, atmp, jac_config, linsolve1, linsolve2, rtol, atol, step_limiter! = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    (; T, TI, γ, α, β, c, e) = tab
+    (; κ, derivatives, z, w, c_prime, αdt, βdt) = cache
+    (; dw1, ubuff, dw2, cubuff, dw) = cache
+    (; ks, k, fw, J, W1, W2) = cache
+    (; tmp, atmp, jac_config, linsolve1, linsolve2, rtol, atol, step_limiter!) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations
@@ -1390,7 +1399,7 @@ function _ode_addsteps!(integrator, cache::AdaptiveRadauCache, repeat_step = fal
     end
 
     if integrator.opts.adaptive
-        @unpack abstol, reltol = integrator.opts
+        (; abstol, reltol) = integrator.opts
         if reltol isa Number
             cache.rtol = reltol^((num_stages + 1) / (2 * num_stages)) / 10
             cache.atol = cache.rtol * (abstol / reltol)
@@ -1460,7 +1469,8 @@ function _ode_addsteps!(integrator, cache::AdaptiveRadauCache, repeat_step = fal
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -1528,7 +1538,6 @@ function _ode_addsteps!(integrator, cache::AdaptiveRadauCache, repeat_step = fal
                 needfactor = needfactor
 
                 @threaded alg.threading for i in 1:((num_stages - 1) ÷ 2)
-                    #@show i == Threads.threadid()
                     @.. cubuff[i]=complex(
                         fw[2 * i] - αdt[i] * Mw[2 * i] + βdt[i] * Mw[2 * i + 1],
                         fw[2 * i + 1] - βdt[i] * Mw[2 * i] - αdt[i] * Mw[2 * i + 1])
@@ -1553,7 +1562,7 @@ function _ode_addsteps!(integrator, cache::AdaptiveRadauCache, repeat_step = fal
         end
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         calculate_residuals!(atmp, dw1, uprev, u, atol, rtol, internalnorm, t)
         ndw = internalnorm(atmp, t)
         for i in 2:num_stages
@@ -1571,6 +1580,7 @@ function _ode_addsteps!(integrator, cache::AdaptiveRadauCache, repeat_step = fal
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         @.. w[1] = w[1] - dw1
@@ -1594,7 +1604,6 @@ function _ode_addsteps!(integrator, cache::AdaptiveRadauCache, repeat_step = fal
         end
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
