@@ -49,7 +49,7 @@ function initialize!(integrator, cache::RadauIIA3Cache)
     integrator.f(integrator.fsalfirst, integrator.uprev, integrator.p, integrator.t)
     OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
     if integrator.opts.adaptive
-        @unpack abstol, reltol = integrator.opts
+        (; abstol, reltol) = integrator.opts
         if reltol isa Number
             cache.rtol = reltol^(2 / 3) / 10
             cache.atol = cache.rtol * (abstol / reltol)
@@ -88,7 +88,7 @@ function initialize!(integrator, cache::RadauIIA5Cache)
     integrator.f(integrator.fsalfirst, integrator.uprev, integrator.p, integrator.t)
     OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
     if integrator.opts.adaptive
-        @unpack abstol, reltol = integrator.opts
+        (; abstol, reltol) = integrator.opts
         if reltol isa Number
             cache.rtol = reltol^(2 / 3) / 10
             cache.atol = cache.rtol * (abstol / reltol)
@@ -131,7 +131,7 @@ function initialize!(integrator, cache::RadauIIA9Cache)
     integrator.f(integrator.fsalfirst, integrator.uprev, integrator.p, integrator.t)
     OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
     if integrator.opts.adaptive
-        @unpack abstol, reltol = integrator.opts
+        (; abstol, reltol) = integrator.opts
         if reltol isa Number
             cache.rtol = reltol^(3 / 5) / 10
             cache.atol = cache.rtol * (abstol / reltol)
@@ -175,13 +175,13 @@ function initialize!(integrator, cache::AdaptiveRadauCache)
 end
 
 @muladd function perform_step!(integrator, cache::RadauIIA3ConstantCache)
-    @unpack t, dt, uprev, u, f, p, k = integrator
-    @unpack T11, T12, T21, T22, TI11, TI12, TI21, TI22 = cache.tab
-    @unpack c1, c2, α, β, e1, e2 = cache.tab
-    @unpack κ = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    (; t, dt, uprev, u, f, p, k) = integrator
+    (; T11, T12, T21, T22, TI11, TI12, TI21, TI22) = cache.tab
+    (; c1, c2, α, β, e1, e2) = cache.tab
+    (; κ) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations
@@ -217,7 +217,10 @@ end
     integrator.stats.nw += 1
 
     # Newton iteration
-    local ndw, ff1, ff2
+    # Initialize variables for JET
+    ndw = one(eltype(u))
+    ff1 = zero(u)
+    ff2 = zero(u)
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -248,7 +251,7 @@ end
         dw2 = imag(dw12)
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         atmp1 = calculate_residuals(dw1, uprev, u, atol, rtol, internalnorm, t)
         atmp2 = calculate_residuals(dw2, uprev, u, atol, rtol, internalnorm, t)
         ndw = internalnorm(atmp1, t) + internalnorm(atmp2, t)
@@ -262,6 +265,7 @@ end
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         w1 = @. w1 - dw1
@@ -272,7 +276,6 @@ end
         z2 = @. T21 * w1 + T22 * w2
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -309,18 +312,18 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::RadauIIA3Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, fsallast, fsalfirst, k = integrator
-    @unpack T11, T12, T21, T22, TI11, TI12, TI21, TI22 = cache.tab
-    @unpack c1, c2, α, β, e1, e2 = cache.tab
-    @unpack κ = cache
-    @unpack z1, z2, w1, w2,
+    (; t, dt, uprev, u, f, p, fsallast, fsalfirst, k) = integrator
+    (; T11, T12, T21, T22, TI11, TI12, TI21, TI22) = cache.tab
+    (; c1, c2, α, β, e1, e2) = cache.tab
+    (; κ) = cache
+    (; z1, z2, w1, w2,
     dw12, cubuff,
     k, k2, fw1, fw2,
     J, W1,
-    tmp, atmp, jac_config, rtol, atol, step_limiter! = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    tmp, atmp, jac_config, rtol, atol, step_limiter!) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
     # precalculations
     αdt, βdt = α / dt, β / dt
@@ -353,7 +356,8 @@ end
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -405,7 +409,7 @@ end
         dw2 = imag(dw12)
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         calculate_residuals!(atmp, dw1, uprev, u, atol, rtol, internalnorm, t)
         ndw1 = internalnorm(atmp, t)
         calculate_residuals!(atmp, dw2, uprev, u, atol, rtol, internalnorm, t)
@@ -419,6 +423,7 @@ end
             if diverge
                 break
             end
+            η = θ / (1 - θ)
         end
 
         @. w1 = w1 - dw1
@@ -429,7 +434,6 @@ end
         @. z2 = T21 * w1 + T22 * w2
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -471,14 +475,14 @@ end
 
 @muladd function perform_step!(integrator, cache::RadauIIA5ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, k = integrator
-    @unpack T11, T12, T13, T21, T22, T23, T31, TI11, TI12, TI13,
-    TI21, TI22, TI23, TI31, TI32, TI33 = cache.tab
-    @unpack c1, c2, γ, α, β, e1, e2, e3 = cache.tab
-    @unpack κ, cont1, cont2, cont3 = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    (; t, dt, uprev, u, f, p, k) = integrator
+    (; T11, T12, T13, T21, T22, T23, T31, TI11, TI12, TI13,
+    TI21, TI22, TI23, TI31, TI32, TI33) = cache.tab
+    (; c1, c2, γ, α, β, e1, e2, e3) = cache.tab
+    (; κ, cont1, cont2, cont3) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations
@@ -524,7 +528,8 @@ end
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -562,7 +567,7 @@ end
         dw3 = imag(dw23)
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         atmp1 = calculate_residuals(dw1, uprev, u, atol, rtol, internalnorm, t)
         atmp2 = calculate_residuals(dw2, uprev, u, atol, rtol, internalnorm, t)
         atmp3 = calculate_residuals(dw3, uprev, u, atol, rtol, internalnorm, t)
@@ -576,6 +581,7 @@ end
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         w1 = @.. w1-dw1
@@ -588,7 +594,6 @@ end
         z3 = @.. T31 * w1+w2           # T32 = 1, T33 = 0
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -651,19 +656,20 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::RadauIIA5Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, fsallast, fsalfirst, k = integrator
-    @unpack T11, T12, T13, T21, T22, T23, T31, TI11, TI12, TI13,
-    TI21, TI22, TI23, TI31, TI32, TI33 = cache.tab
-    @unpack c1, c2, γ, α, β, e1, e2, e3 = cache.tab
-    @unpack κ = cache
-    @unpack z1, z2, z3, w1, w2, w3,
+    (; t, dt, uprev, u, f, p, fsallast, fsalfirst, k) = integrator
+    (; T11, T12, T13, T21, T22, T23, T31, TI11, TI12, TI13,
+    TI21, TI22, TI23, TI31, TI32, TI33) = cache.tab
+    (; c1, c2, γ, α, β, e1, e2, e3) = cache.tab
+    (; κ) = cache
+    linres1 = nothing
+    (; z1, z2, z3, w1, w2, w3,
     dw1, ubuff, dw23, cubuff,
     k, k2, k3, fw1, fw2, fw3,
     J, W1, W2,
-    tmp, atmp, jac_config, linsolve1, linsolve2, rtol, atol, step_limiter! = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    tmp, atmp, jac_config, linsolve1, linsolve2, rtol, atol, step_limiter!) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations
@@ -710,7 +716,8 @@ end
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -788,7 +795,7 @@ end
         @.. dw3=imag(dw23)
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         calculate_residuals!(atmp, dw1, uprev, u, atol, rtol, internalnorm, t)
         ndw1 = internalnorm(atmp, t)
         calculate_residuals!(atmp, dw2, uprev, u, atol, rtol, internalnorm, t)
@@ -806,6 +813,7 @@ end
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         @.. w1=w1 - dw1
@@ -818,7 +826,6 @@ end
         @.. z3=T31 * w1 + w2           # T32 = 1, T33 = 0
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -893,17 +900,17 @@ end
 
 @muladd function perform_step!(integrator, cache::RadauIIA9ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, k = integrator
-    @unpack T11, T12, T13, T14, T15, T21, T22, T23, T24, T25, T31, T32,
-    T33, T34, T35, T41, T42, T43, T44, T45, T51 = cache.tab#= T52 = 1, T53 = 0, T54 = 1, T55 = 0=#
-    @unpack TI11,
+    (; t, dt, uprev, u, f, p, k) = integrator
+    (; T11, T12, T13, T14, T15, T21, T22, T23, T24, T25, T31, T32,
+    T33, T34, T35, T41, T42, T43, T44, T45, T51) = cache.tab#= T52 = 1, T53 = 0, T54 = 1, T55 = 0=#
+    (; TI11,
     TI12, TI13, TI14, TI15, TI21, TI22, TI23, TI24, TI25, TI31, TI32, TI33, TI34,
-    TI35, TI41, TI42, TI43, TI44, TI45, TI51, TI52, TI53, TI54, TI55 = cache.tab
-    @unpack c1, c2, c3, c4, γ, α1, β1, α2, β2, e1, e2, e3, e4, e5 = cache.tab
-    @unpack κ = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    TI35, TI41, TI42, TI43, TI44, TI45, TI51, TI52, TI53, TI54, TI55) = cache.tab
+    (; c1, c2, c3, c4, γ, α1, β1, α2, β2, e1, e2, e3, e4, e5) = cache.tab
+    (; κ) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations rtol pow is (num stages + 1)/(2*num stages)
@@ -984,7 +991,8 @@ end
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -1035,7 +1043,7 @@ end
         dw5 = imag(dw45)
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         atmp1 = calculate_residuals(dw1, uprev, u, atol, rtol, internalnorm, t)
         atmp2 = calculate_residuals(dw2, uprev, u, atol, rtol, internalnorm, t)
         atmp3 = calculate_residuals(dw3, uprev, u, atol, rtol, internalnorm, t)
@@ -1054,6 +1062,7 @@ end
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         w1 = @.. w1-dw1
@@ -1070,7 +1079,6 @@ end
         z5 = @.. T51*w1+w2+w4#= T52=1, T53=0, T54=1, T55=0 =#
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -1143,23 +1151,24 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::RadauIIA9Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, fsallast, fsalfirst, k = integrator
-    @unpack T11, T12, T13, T14, T15, T21, T22, T23, T24, T25, T31, T32,
-    T33, T34, T35, T41, T42, T43, T44, T45, T51 = cache.tab#= T52 = 1, T53 = 0, T54 = 1, T55 = 0=#
-    @unpack TI11,
+    (; t, dt, uprev, u, f, p, fsallast, fsalfirst, k) = integrator
+    (; T11, T12, T13, T14, T15, T21, T22, T23, T24, T25, T31, T32,
+    T33, T34, T35, T41, T42, T43, T44, T45, T51) = cache.tab#= T52 = 1, T53 = 0, T54 = 1, T55 = 0=#
+    (; TI11,
     TI12, TI13, TI14, TI15, TI21, TI22, TI23, TI24, TI25, TI31, TI32, TI33, TI34,
-    TI35, TI41, TI42, TI43, TI44, TI45, TI51, TI52, TI53, TI54, TI55 = cache.tab
-    @unpack c1, c2, c3, c4, γ, α1, β1, α2, β2, e1, e2, e3, e4, e5 = cache.tab
-    @unpack κ = cache
-    @unpack z1, z2, z3, z4, z5, w1, w2, w3, w4, w5 = cache
-    @unpack dw1, ubuff, dw23, dw45, cubuff1, cubuff2 = cache
-    @unpack k, k2, k3, k4, k5, fw1, fw2, fw3, fw4, fw5 = cache
-    @unpack J, W1, W2, W3 = cache
-    @unpack tmp, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7, tmp8, tmp9, tmp10, atmp, jac_config,
-    linsolve1, linsolve2, linsolve3, rtol, atol, step_limiter! = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    TI35, TI41, TI42, TI43, TI44, TI45, TI51, TI52, TI53, TI54, TI55) = cache.tab
+    (; c1, c2, c3, c4, γ, α1, β1, α2, β2, e1, e2, e3, e4, e5) = cache.tab
+    (; κ) = cache
+    linres1 = nothing
+    (; z1, z2, z3, z4, z5, w1, w2, w3, w4, w5) = cache
+    (; dw1, ubuff, dw23, dw45, cubuff1, cubuff2) = cache
+    (; k, k2, k3, k4, k5, fw1, fw2, fw3, fw4, fw5) = cache
+    (; J, W1, W2, W3) = cache
+    (; tmp, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7, tmp8, tmp9, tmp10, atmp, jac_config,
+    linsolve1, linsolve2, linsolve3, rtol, atol, step_limiter!) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations
@@ -1239,7 +1248,8 @@ end
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -1356,7 +1366,7 @@ end
         @.. dw5=imag(dw45)
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         calculate_residuals!(atmp, dw1, uprev, u, atol, rtol, internalnorm, t)
         ndw1 = internalnorm(atmp, t)
         calculate_residuals!(atmp, dw2, uprev, u, atol, rtol, internalnorm, t)
@@ -1379,6 +1389,7 @@ end
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         @.. w1=w1 - dw1
@@ -1395,8 +1406,6 @@ end
         @.. z5=T51 * w1 + w2 + w4#= T52=1, T53=0, T54=1, T55=0 =#
 
         # check stopping criterion
-
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -1484,14 +1493,14 @@ end
 
 @muladd function perform_step!(integrator, cache::AdaptiveRadauConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, k = integrator
-    @unpack tabs, num_stages, index = cache
+    (; t, dt, uprev, u, f, p, k) = integrator
+    (; tabs, num_stages, index) = cache
     tab = tabs[index]
-    @unpack T, TI, γ, α, β, c, e = tab
-    @unpack κ = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    (; T, TI, γ, α, β, c, e) = tab
+    (; κ) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations rtol pow is (num stages + 1)/(2*num stages)
@@ -1555,7 +1564,8 @@ end
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -1608,7 +1618,7 @@ end
         integrator.stats.nsolve += (num_stages + 1) ÷ 2
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         ndw = 0.0
         for i in 1:num_stages
             ndw += internalnorm(
@@ -1625,6 +1635,7 @@ end
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         for i in 1:num_stages
@@ -1647,7 +1658,6 @@ end
         end
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
@@ -1728,17 +1738,17 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::AdaptiveRadauCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, fsallast, fsalfirst, k = integrator
-    @unpack num_stages, tabs, index = cache
+    (; t, dt, uprev, u, f, p, fsallast, fsalfirst, k) = integrator
+    (; num_stages, tabs, index) = cache
     tab = tabs[index]
-    @unpack T, TI, γ, α, β, c, e = tab
-    @unpack κ, derivatives, z, w, c_prime, αdt, βdt = cache
-    @unpack dw1, ubuff, dw2, cubuff, dw = cache
-    @unpack ks, fw, J, W1, W2 = cache
-    @unpack tmp, atmp, jac_config, linsolve1, linsolve2, rtol, atol, step_limiter! = cache
-    @unpack internalnorm, abstol, reltol, adaptive = integrator.opts
+    (; T, TI, γ, α, β, c, e) = tab
+    (; κ, derivatives, z, w, c_prime, αdt, βdt) = cache
+    (; dw1, ubuff, dw2, cubuff, dw) = cache
+    (; ks, fw, J, W1, W2) = cache
+    (; tmp, atmp, jac_config, linsolve1, linsolve2, rtol, atol, step_limiter!) = cache
+    (; internalnorm, abstol, reltol, adaptive) = integrator.opts
     alg = unwrap_alg(integrator, true)
-    @unpack maxiters = alg
+    (; maxiters) = alg
     mass_matrix = integrator.f.mass_matrix
 
     # precalculations
@@ -1749,7 +1759,7 @@ end
     end
 
     if integrator.opts.adaptive
-        @unpack abstol, reltol = integrator.opts
+        (; abstol, reltol) = integrator.opts
         if reltol isa Number
             cache.rtol = reltol^((num_stages + 1) / (2 * num_stages)) / 10
             cache.atol = cache.rtol * (abstol / reltol)
@@ -1819,7 +1829,8 @@ end
     end
 
     # Newton iteration
-    local ndw
+    # Initialize variables for JET
+    ndw = one(eltype(u))
     η = max(cache.ηold, eps(eltype(integrator.opts.reltol)))^(0.8)
     fail_convergence = true
     iter = 0
@@ -1887,7 +1898,6 @@ end
                 needfactor = needfactor
 
                 @threaded alg.threading for i in 1:((num_stages - 1) ÷ 2)
-                    #@show i == Threads.threadid()
                     @.. cubuff[i] = complex(
                         fw[2 * i] - αdt[i] * Mw[2 * i] + βdt[i] * Mw[2 * i + 1],
                         fw[2 * i + 1] - βdt[i] * Mw[2 * i] - αdt[i] * Mw[2 * i + 1])
@@ -1912,7 +1922,7 @@ end
         end
 
         # compute norm of residuals
-        iter > 1 && (ndwprev = ndw)
+        ndwprev = ndw
         calculate_residuals!(atmp, dw1, uprev, u, atol, rtol, internalnorm, t)
         ndw = internalnorm(atmp, t)
         for i in 2:num_stages
@@ -1930,6 +1940,7 @@ end
             if diverge || veryslowconvergence
                 break
             end
+            η = θ / (1 - θ)
         end
 
         @.. w[1] = w[1] - dw1
@@ -1953,7 +1964,6 @@ end
         end
 
         # check stopping criterion
-        iter > 1 && (η = θ / (1 - θ))
         if η * ndw < κ && (iter > 1 || iszero(ndw) || !iszero(integrator.success_iter))
             # Newton method converges
             cache.status = η < alg.fast_convergence_cutoff ? FastConvergence :
